==> bibletime_1.1-4.tar.gz: bibletime-1.1/bibletime/backend/cswordcommentarymoduleinfo.h <==
/***************************************************************************
                          cswordcommentarymoduleinfo.h  -  description
                             -------------------
    begin                : Thu Oct 5 2000
    copyright            : (C) 2000 by The BibleTime team
    email                : info@bibletime.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSWORDCOMMENTARYMODULEINFO_H
#define CSWORDCOMMENTARYMODULEINFO_H

//own includes
#include "cswordbiblemoduleinfo.h"

//Qt includes

//Sword includes

/**
  * @author The BibleTime team
  * @version $Id: cswordcommentarymoduleinfo.h,v 1.3 2002/02/22 20:55:12 joachim Exp $
  */
class CSwordCommentaryModuleInfo : public CSwordBibleModuleInfo  {
public:
	CSwordCommentaryModuleInfo( SWModule* module );
	~CSwordCommentaryModuleInfo();
  virtual const CSwordModuleInfo::ModuleType type() const;
  virtual CSwordModuleInfo* clone();
};

/** No descriptions */
inline const CSwordModuleInfo::ModuleType CSwordCommentaryModuleInfo::type() const{
	return CSwordModuleInfo::Commentary;
}

#endif

==> bibletime_1.4.1.orig.tar.gz: bibletime-1.4.1/bibletime/backend/cswordcommentarymoduleinfo.h <==
/***************************************************************************
                          cswordcommentarymoduleinfo.h  -  description
                             -------------------
    begin                : Thu Oct 5 2000
    copyright            : (C) 2000 by The BibleTime team
    email                : info@bibletime.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSWORDCOMMENTARYMODULEINFO_H
#define CSWORDCOMMENTARYMODULEINFO_H

//own includes
#include "cswordbiblemoduleinfo.h"

/**
  * @author The BibleTime team
  * @version $Id: cswordcommentarymoduleinfo.h,v 1.7 2004/01/29 00:36:48 joachim Exp $
  */
class CSwordCommentaryModuleInfo : public CSwordBibleModuleInfo  {
public:
	CSwordCommentaryModuleInfo( sword::SWModule* module, CSwordBackend* const = CPointers::backend() );
	~CSwordCommentaryModuleInfo();
  virtual const CSwordModuleInfo::ModuleType type() const;
  virtual CSwordModuleInfo* clone();
  /**
  * Returns true if this module may be written by the write display windows.
  */
  virtual const bool isWritable();
};

/** No descriptions */
inline const CSwordModuleInfo::ModuleType CSwordCommentaryModuleInfo::type() const{
	return CSwordModuleInfo::Commentary;
}

#endif
